@@ -43,16 +43,21 @@ extern "C" {
 #include <camel/camel-disco-store.h>
 #include <camel/camel-vee-folder.h>
 #include <camel/camel-medium.h>
+#include <camel/camel-mime-filter.h>
 #include <camel/camel-mime-filter-basic.h>
+#include <camel/camel-mime-filter-bestenc.h>
 #include <camel/camel-mime-filter-canon.h>
 #include <camel/camel-mime-filter-charset.h>
+#include <camel/camel-mime-filter-crlf.h>
 #include <camel/camel-mime-filter-enriched.h>
 #include <camel/camel-mime-filter-from.h>
+#include <camel/camel-mime-filter-gzip.h>
+#include <camel/camel-mime-filter-html.h>
 #include <camel/camel-mime-filter-index.h>
+#include <camel/camel-mime-filter-linewrap.h>
 #include <camel/camel-mime-filter-save.h>
-#include <camel/camel-mime-filter-crlf.h>
 #include <camel/camel-mime-filter-tohtml.h>
-#include <camel/camel-mime-filter.h>
+#include <camel/camel-mime-filter-yenc.h>
 #include <camel/camel-mime-message.h>
 #include <camel/camel-mime-parser.h>
 #include <camel/camel-mime-part-utils.h>
@@ -82,7 +87,7 @@ extern "C" {
 #include <camel/camel-url.h>
 #include <camel/camel-string-utils.h>
 
-gint camel_init (const char *certdb_dir, gboolean nss_init);
+int camel_init (const char *certdb_dir, gboolean nss_init);
 
 #ifdef __cplusplus
 }
