@@ -3,14 +3,15 @@
 
 #include <stdio.h>
 #include <string.h>
-#include <signal.h>
-
-#ifdef ENABLE_THREADS
+#include <sys/stat.h>
+#include <sys/types.h>
 #include <pthread.h>
 #include <unistd.h>
-#endif
+#include <signal.h>
+#include <errno.h>
+
+#include <camel/camel.h>
 
-#ifdef ENABLE_THREADS
 /* well i dunno, doesn't seem to be in the headers but hte manpage mentions it */
 /* a nonportable checking mutex for glibc, not really needed, just validates
    the test harness really */
@@ -22,11 +23,6 @@ static pthread_mutex_t lock = PTHREAD_MUTEX_INITIALIZER;
 #define CAMEL_TEST_LOCK pthread_mutex_lock(&lock)
 #define CAMEL_TEST_UNLOCK pthread_mutex_unlock(&lock)
 #define CAMEL_TEST_ID (pthread_self())
-#else
-#define CAMEL_TEST_LOCK
-#define CAMEL_TEST_UNLOCK
-#define CAMEL_TEST_ID (0)
-#endif
 
 static int setup;
 static int ok;
@@ -52,10 +48,9 @@ static void
 dump_action(int id, struct _state *s, void *d)
 {
 	struct _stack *node;
-
-#ifdef ENABLE_THREADS
+	
 	printf("\nThread %d:\n", id);
-#endif
+	
 	node = s->state;
 	if (node) {
 		printf("Current action:\n");
@@ -75,13 +70,11 @@ static void die(int sig)
 		indie = 1;
 		printf("\n\nReceived fatal signal %d\n", sig);
 		g_hash_table_foreach(info_table, (GHFunc)dump_action, 0);
-
-#ifdef ENABLE_THREADS
+		
 		if (camel_test_verbose > 2) {
 			printf("Attach debugger to pid %d to debug\n", getpid());
 			sleep(1000);
 		}
-#endif
 	}
 
 	_exit(1);
@@ -106,20 +99,32 @@ current_state(void)
 
 void camel_test_init(int argc, char **argv)
 {
-	void camel_init(void);
+	struct stat st;
+	char *path;
 	int i;
-
+	
 	setup = 1;
-
-#ifndef ENABLE_THREADS
-	camel_init();
-#endif
-
-	info_table = g_hash_table_new(0, 0);
-
+	
 	/* yeah, we do need ot thread init, even though camel isn't compiled with enable threads */
-	g_thread_init(NULL);
-
+	g_thread_init (NULL);
+	
+	path = g_strdup_printf ("/tmp/camel-test");
+	if (mkdir (path, 0700) == -1 && errno != EEXIST)
+		abort ();
+	
+	if (stat (path, &st) == -1)
+		abort ();
+	
+	if (!S_ISDIR (st.st_mode) || access (path, R_OK | W_OK | X_OK) == -1)
+		abort ();
+	
+	camel_init (path, FALSE);
+	g_free (path);
+	
+	camel_type_init ();
+	
+	info_table = g_hash_table_new(0, 0);
+	
 	signal(SIGSEGV, die);
 	signal(SIGABRT, die);
 
