@@ -22,21 +22,40 @@
  *
  */
 
-
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
 
+#include <glib.h>
+
 #include <string.h>
 #include <stdarg.h>
+#include <sys/stat.h>
 
-#include <gconf/gconf.h>
 #include <gconf/gconf-client.h>
 
+#include <gtk/gtkentry.h>
+#include <gtk/gtktogglebutton.h>
+#include <gtk/gtktextbuffer.h>
+#include <gtk/gtktextview.h>
+#include <gtk/gtkcheckbutton.h>
+#include <gtk/gtkspinbutton.h>
+#include <gtk/gtkmenuitem.h>
+#include <gtk/gtkoptionmenu.h>
+#include <gtk/gtknotebook.h>
+#include <gtk/gtkhbox.h>
+#include <gtk/gtkdialog.h>
+#ifdef USE_GTKFILECHOOSER
+#include <gtk/gtkfilechooser.h>
+#include <gtk/gtkradiobutton.h>
+#include <libgnomeui/gnome-file-entry.h>
+#endif
+
 #include <e-util/e-account-list.h>
-#include <e-util/e-dialog-utils.h>
 #include <e-util/e-signature-list.h>
 
+#include <widgets/misc/e-error.h>
+
 #include "em-account-prefs.h"
 #include "em-folder-selection-button.h"
 #include "mail-account-gui.h"
@@ -155,6 +174,105 @@ auto_detected_foreach (gpointer key, gpointer value, gpointer user_data)
 	g_free (value);
 }
 
+static void
+check_button_state (GtkToggleButton *button, gpointer data)
+{
+	if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON (button)))
+		gtk_widget_set_sensitive (GTK_WIDGET (data), TRUE);
+	else
+		gtk_widget_set_sensitive (GTK_WIDGET (data), FALSE);
+}
+
+
+static gboolean
+populate_text_entry (GtkTextView *view, const char *filename)
+{
+	FILE *fd;
+	char *filebuf;
+	GtkTextIter iter;
+	GtkTextBuffer *buffer;
+	int count;
+
+	g_return_val_if_fail (filename != NULL , FALSE);
+
+	fd = fopen (filename, "r");
+	
+	if (!fd) {
+		/* FIXME: Should never come here */
+		return FALSE;
+	}
+	
+	filebuf = g_malloc (1024);
+
+	buffer =  gtk_text_buffer_new (NULL);
+	gtk_text_buffer_get_start_iter (buffer, &iter);
+
+	while (!feof (fd) && !ferror (fd)) {
+		count = fread (filebuf, 1, sizeof (filebuf), fd);
+		gtk_text_buffer_insert (buffer, &iter, filebuf, count);
+	}
+	gtk_text_view_set_buffer (GTK_TEXT_VIEW (view), 
+					GTK_TEXT_BUFFER (buffer));
+	fclose (fd);
+	g_free (filebuf);
+	return TRUE;
+}
+
+static gboolean
+display_license (CamelProvider *prov)
+{
+	GladeXML *xml;
+	GtkWidget *top_widget;
+	GtkTextView *text_entry;
+	GtkButton *button_yes, *button_no;
+	GtkCheckButton *check_button;
+	GtkResponseType response = GTK_RESPONSE_NONE;
+	GtkLabel *top_label;
+	char *label_text, *dialog_title;
+	gboolean status;
+	
+	xml = glade_xml_new (EVOLUTION_GLADEDIR "/mail-dialogs.glade", "lic_dialog", NULL);
+	
+	top_widget = glade_xml_get_widget (xml, "lic_dialog");
+	text_entry = GTK_TEXT_VIEW (glade_xml_get_widget (xml, "textview1"));
+	if (!(status = populate_text_entry (GTK_TEXT_VIEW (text_entry), prov->license_file)))
+		goto failed;
+	
+	gtk_text_view_set_editable (GTK_TEXT_VIEW (text_entry), FALSE);
+	
+	button_yes = GTK_BUTTON (glade_xml_get_widget (xml, "lic_yes_button"));
+	gtk_widget_set_sensitive (GTK_WIDGET (button_yes), FALSE);
+	
+	button_no = GTK_BUTTON (glade_xml_get_widget (xml, "lic_no_button"));
+	
+	check_button = GTK_CHECK_BUTTON (glade_xml_get_widget (xml, "lic_checkbutton"));
+	
+	top_label = GTK_LABEL (glade_xml_get_widget (xml, "lic_top_label"));
+	
+	label_text = g_strdup_printf (_("\nPlease read carefully the license agreement\n" 
+					"for %s displayed below\n" 
+					"and tick the check box for accepting it\n"), prov->license);
+	
+	gtk_label_set_label (top_label, label_text);
+	
+	dialog_title = g_strdup_printf (_("%s License Agreement"), prov->license);
+	
+	gtk_window_set_title (GTK_WINDOW (top_widget), dialog_title);
+	
+	g_signal_connect (check_button, "toggled", G_CALLBACK (check_button_state), button_yes);
+	
+	response = gtk_dialog_run (GTK_DIALOG (top_widget));
+	
+	g_free (label_text);
+	g_free (dialog_title);
+	
+ failed:
+	gtk_widget_destroy (top_widget);
+	g_object_unref (xml);
+	
+	return (response == GTK_RESPONSE_ACCEPT);
+}
+
 static gboolean
 service_complete (MailAccountGuiService *service, GHashTable *extra_config, GtkWidget **incomplete)
 {
@@ -215,6 +333,48 @@ service_complete (MailAccountGuiService *service, GHashTable *extra_config, GtkW
 	return TRUE;
 }
 
+static gboolean
+mail_account_gui_check_for_license (CamelProvider *prov)
+{
+	GConfClient *gconf;
+	gboolean accepted = TRUE, status;
+	GSList * providers_list, *l, *n;
+	char *provider;
+
+	if (prov->flags & CAMEL_PROVIDER_HAS_LICENSE) {
+		gconf = mail_config_get_gconf_client ();
+		
+		providers_list = gconf_client_get_list (gconf, "/apps/evolution/mail/licenses", GCONF_VALUE_STRING, NULL);
+		
+		for (l = providers_list, accepted = FALSE; l && !accepted; l = g_slist_next (l))
+			accepted = (strcmp ((char *)l->data, prov->protocol) == 0);
+		if (!accepted) {
+			/* Since the license is not yet accepted, pop-up a 
+			 * dialog to display the license agreement and check 
+			 * if the user accepts it
+			 */
+
+			if ((accepted = display_license (prov)) == TRUE) {
+				provider = g_strdup (prov->protocol);
+				providers_list = g_slist_append (providers_list,
+						 provider);
+				status = gconf_client_set_list (gconf, 
+						"/apps/evolution/mail/licenses",
+						GCONF_VALUE_STRING,
+						 providers_list, NULL);
+			}
+		}
+		l = providers_list;
+		while (l) {
+			n = g_slist_next (l);
+			g_free (l->data);
+			g_slist_free_1 (l);
+			l = n;
+		}
+	}
+	return accepted;
+}
+
 gboolean
 mail_account_gui_source_complete (MailAccountGui *gui, GtkWidget **incomplete)
 {
@@ -492,6 +652,7 @@ source_type_changed (GtkWidget *widget, gpointer user_data)
 	GtkWidget *file_entry, *label, *frame, *dwidget = NULL;
 	CamelProvider *provider;
 	gboolean writeable;
+	gboolean license_accepted = TRUE;
 	
 	provider = g_object_get_data ((GObject *) widget, "provider");
 	
@@ -521,8 +682,11 @@ source_type_changed (GtkWidget *widget, gpointer user_data)
 	else
 		gtk_label_set_text (gui->source.description, "");
 	
+	if (gui->source.provider)	
+		license_accepted = mail_account_gui_check_for_license (gui->source.provider);
+
 	frame = glade_xml_get_widget (gui->xml, "source_frame");
-	if (provider) {
+	if (provider && license_accepted) {
 		gtk_widget_show (frame);
 		
 		/* hostname */
@@ -759,19 +923,22 @@ toggle_sensitivity (GtkToggleButton *toggle, GtkWidget *widget)
 	gtk_widget_set_sensitive (widget, gtk_toggle_button_get_active (toggle));
 }
 
-static void
+/* Returns true if the widget is enabled */
+static gboolean
 setup_toggle (GtkWidget *widget, const char *depname, MailAccountGui *gui)
 {
 	GtkToggleButton *toggle;
 	
 	if (!strcmp (depname, "UNIMPLEMENTED")) {
 		gtk_widget_set_sensitive (widget, FALSE);
-		return;
+		return FALSE;
 	}
 	
 	toggle = g_hash_table_lookup (gui->extra_config, depname);
 	g_signal_connect (toggle, "toggled", G_CALLBACK (toggle_sensitivity), widget);
 	toggle_sensitivity (toggle, widget);
+
+	return gtk_toggle_button_get_active(toggle);
 }
 
 void
@@ -861,6 +1028,7 @@ mail_account_gui_build_extra_conf (MailAccountGui *gui, const char *url_string)
 	rows = main_table->nrows;
 	for (i = 0; ; i++) {
 		GtkWidget *enable_widget = NULL;
+		int enabled = TRUE;
 		
 		switch (entries[i].type) {
 		case CAMEL_PROVIDER_CONF_SECTION_START:
@@ -949,8 +1117,8 @@ mail_account_gui_build_extra_conf (MailAccountGui *gui, const char *url_string)
 			rows++;
 			g_hash_table_insert (gui->extra_config, entries[i].name, checkbox);
 			if (entries[i].depname)
-				setup_toggle (checkbox, entries[i].depname, gui);
-			
+				enabled = setup_toggle(checkbox, entries[i].depname, gui);
+
 			enable_widget = checkbox;
 			break;
 		}
@@ -995,7 +1163,7 @@ mail_account_gui_build_extra_conf (MailAccountGui *gui, const char *url_string)
 			
 			if (entries[i].depname) {
 				setup_toggle (entry, entries[i].depname, gui);
-				setup_toggle (label, entries[i].depname, gui);
+				enabled = setup_toggle (label, entries[i].depname, gui);
 			}
 			
 			g_hash_table_insert (gui->extra_config, entries[i].name, entry);
@@ -1062,18 +1230,21 @@ mail_account_gui_build_extra_conf (MailAccountGui *gui, const char *url_string)
 			if (entries[i].depname) {
 				setup_toggle (checkbox, entries[i].depname, gui);
 				setup_toggle (spin, entries[i].depname, gui);
-				setup_toggle (label, entries[i].depname, gui);
+				enabled = setup_toggle (label, entries[i].depname, gui);
 			}
 			
 			enable_widget = hbox;
 			break;
 		}
-		
+
+		case CAMEL_PROVIDER_CONF_HIDDEN:
+			break;
+
 		case CAMEL_PROVIDER_CONF_END:
 			goto done;
 		}
 		
-		if (enable_widget)
+		if (enabled && enable_widget)
 			gtk_widget_set_sensitive(enable_widget, e_account_writable_option(gui->account, gui->source.provider->protocol, entries[i].name));
 	}
 	
@@ -1132,7 +1303,12 @@ extract_values (MailAccountGuiService *source, GHashTable *extra_config, CamelUR
 			camel_url_set_param (url, entries[i].name, name);
 			g_free (name);
 			break;
-			
+
+		case CAMEL_PROVIDER_CONF_HIDDEN:
+			if (entries[i].value)
+				camel_url_set_param (url, entries[i].name, entries[i].value);
+			break;
+
 		case CAMEL_PROVIDER_CONF_END:
 			return;
 			
@@ -1301,6 +1477,16 @@ construct_ssl_menu (MailAccountGuiService *service)
 	g_signal_emit_by_name (item, "activate", service);
 }
 
+static void
+sig_activate (GtkWidget *item, MailAccountGui *gui)
+{
+	ESignature *sig;
+	
+	sig = g_object_get_data ((GObject *) item, "sig");
+	
+	gui->sig_uid = sig ? sig->uid : NULL;
+}
+
 static void
 signature_added (ESignatureList *signatures, ESignature *sig, MailAccountGui *gui)
 {
@@ -1312,6 +1498,7 @@ signature_added (ESignatureList *signatures, ESignature *sig, MailAccountGui *gu
 	else
 		item = gtk_menu_item_new_with_label (sig->name);
 	g_object_set_data ((GObject *) item, "sig", sig);
+	g_signal_connect (item, "activate", G_CALLBACK (sig_activate), gui);
 	gtk_widget_show (item);
 	
 	gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
@@ -1389,6 +1576,7 @@ sig_fill_menu (MailAccountGui *gui)
 	
 	item = gtk_menu_item_new_with_label (_("None"));
 	gtk_widget_show (item);
+	g_signal_connect (item, "activate", G_CALLBACK (sig_activate), gui);
 	gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
 	
 	signatures = mail_config_get_signatures ();
@@ -1411,18 +1599,6 @@ sig_fill_menu (MailAccountGui *gui)
 	gtk_option_menu_set_history (gui->sig_menu, 0);
 }
 
-static void
-sig_changed (GtkWidget *menu, MailAccountGui *gui)
-{
-	GtkWidget *active;
-	ESignature *sig;
-	
-	active = gtk_menu_get_active (GTK_MENU (menu));
-	sig = g_object_get_data ((GObject *) active, "sig");
-	
-	gui->sig_uid = sig ? sig->uid : NULL;
-}
-
 static void
 sig_switch_to_list (GtkWidget *w, MailAccountGui *gui)
 {
@@ -1449,7 +1625,7 @@ sig_add_new_signature (GtkWidget *w, MailAccountGui *gui)
 	parent = gtk_widget_get_toplevel (w);
 	parent = GTK_WIDGET_TOPLEVEL (parent) ? parent : NULL;
 	
-	em_composer_prefs_new_signature ((GtkWindow *) parent, send_html, NULL);
+	em_composer_prefs_new_signature ((GtkWindow *) parent, send_html);
 }
 
 static void
@@ -1469,6 +1645,7 @@ select_account_signature (MailAccountGui *gui)
 		cur = g_object_get_data (items->data, "sig");
 		if (cur == sig) {
 			gtk_option_menu_set_history (gui->sig_menu, i);
+			gtk_menu_item_activate (items->data);
 			break;
 		}
 		items = items->next;
@@ -1484,9 +1661,6 @@ prepare_signatures (MailAccountGui *gui)
 	gui->sig_menu = (GtkOptionMenu *) glade_xml_get_widget (gui->xml, "sigOption");
 	sig_fill_menu (gui);
 	
-	g_signal_connect (gtk_option_menu_get_menu (gui->sig_menu),
-			  "selection-done", G_CALLBACK(sig_changed), gui);
-	
 	button = glade_xml_get_widget (gui->xml, "sigAddNew");
 	g_signal_connect (button, "clicked", G_CALLBACK (sig_add_new_signature), gui);
 	
@@ -1585,10 +1759,49 @@ smime_encrypt_key_clear(GtkWidget *w, MailAccountGui *gui)
 }
 #endif
 
+#ifdef USE_GTKFILECHOOSER
+static void
+select_file_toggled (GtkToggleButton *toggle, GtkFileChooser *chooser)
+{
+	GtkFileChooserAction action = GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER;
+	
+	if (gtk_toggle_button_get_active (toggle))
+		action = GTK_FILE_CHOOSER_ACTION_OPEN;
+	
+	gtk_file_chooser_set_action (chooser, action);
+}
+
+static void
+browse_clicked (GnomeFileEntry *fentry, MailAccountGui *gui)
+{
+	GtkWidget *check;
+	struct stat st;
+	char *path;
+	
+	if (GTK_IS_FILE_CHOOSER (fentry->fsw)) {
+		check = gtk_check_button_new_with_label (_("Select a file"));
+		g_signal_connect (check, "toggled", G_CALLBACK (select_file_toggled), fentry->fsw);
+		gtk_widget_show (check);
+		gtk_file_chooser_set_extra_widget (GTK_FILE_CHOOSER (fentry->fsw), check);
+		
+		path = gnome_file_entry_get_full_path (fentry, TRUE);
+		if (path && stat (path, &st) == 0 && S_ISREG (st.st_mode))
+			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (check), TRUE);
+		else
+			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (check), FALSE);
+		gtk_toggle_button_toggled (GTK_TOGGLE_BUTTON (check));
+		g_free (path);
+	}
+	
+	g_signal_handlers_disconnect_by_func (fentry, G_CALLBACK (fentry), gui);
+}
+#endif /* USE_GTKFILECHOOSER */
+
 MailAccountGui *
 mail_account_gui_new (EAccount *account, EMAccountPrefs *dialog)
 {
 	MailAccountGui *gui;
+	GtkWidget *fileentry;
 	
 	g_object_ref (account);
 	
@@ -1597,6 +1810,15 @@ mail_account_gui_new (EAccount *account, EMAccountPrefs *dialog)
 	gui->dialog = dialog;
 	gui->xml = glade_xml_new (EVOLUTION_GLADEDIR "/mail-config.glade", NULL, NULL);
 	
+#ifdef USE_GTKFILECHOOSER
+	/* KLUDGE: If this Evolution was built with GtkFileChooser support, the user
+	 * won't be able to create some types of local accounts because GtkFileChooser
+	 * must be set to allow selection of one or the other of file vs folder.
+	 * However, some providers allow the selection of files *or* folders. */
+	fileentry = glade_xml_get_widget (gui->xml, "source_path_entry");
+	g_signal_connect_after (fileentry, "browse-clicked", G_CALLBACK (browse_clicked), gui);
+#endif
+	
 	/* Management */
 	gui->account_name = GTK_ENTRY (glade_xml_get_widget (gui->xml, "management_name"));
 	gui->default_account = GTK_TOGGLE_BUTTON (glade_xml_get_widget (gui->xml, "management_default"));
@@ -1758,7 +1980,7 @@ mail_account_gui_new (EAccount *account, EMAccountPrefs *dialog)
 		/* Since we don't have NSS, hide the S/MIME config options */
 		GtkWidget *frame;
 		
-		frame = glade_xml_get_widget (gui->xml, "smime_frame");
+		frame = glade_xml_get_widget (gui->xml, "smime_vbox");
 		gtk_widget_destroy (frame);
 	}
 #endif /* HAVE_NSS */
@@ -1769,7 +1991,7 @@ mail_account_gui_new (EAccount *account, EMAccountPrefs *dialog)
 void
 mail_account_gui_setup (MailAccountGui *gui, GtkWidget *top)
 {
-	GtkWidget *stores, *transports, *item;
+	GtkWidget *stores, *transports, *item, *none;
 	GtkWidget *fstore = NULL, *ftransport = NULL;
 	int si = 0, hstore = 0, ti = 0, htransport = 0;
 	int max_width = 0;
@@ -1795,6 +2017,15 @@ mail_account_gui_setup (MailAccountGui *gui, GtkWidget *top)
 	/* Construct source/transport option menus */
 	stores = gtk_menu_new ();
 	transports = gtk_menu_new ();
+
+	/* add a "None" option to the stores menu */
+	none = item = gtk_menu_item_new_with_label (_("None"));
+	g_object_set_data ((GObject *) item, "provider", NULL);
+	g_signal_connect (item, "activate", G_CALLBACK (source_type_changed), gui);
+	gtk_menu_shell_append(GTK_MENU_SHELL(stores), item);
+	gtk_widget_show (item);
+	si++;
+
 	providers = camel_provider_list(TRUE);
 	
 	/* sort the providers, remote first */
@@ -1845,7 +2076,8 @@ mail_account_gui_setup (MailAccountGui *gui, GtkWidget *top)
 			if (CAMEL_PROVIDER_IS_STORE_AND_TRANSPORT (provider))
 				gtk_widget_set_sensitive (item, FALSE);
 			
-			if (!ftransport) {
+			if (!ftransport
+			    && !CAMEL_PROVIDER_IS_STORE_AND_TRANSPORT (provider)) {
 				ftransport = item;
 				htransport = ti;
 			}
@@ -1880,18 +2112,9 @@ mail_account_gui_setup (MailAccountGui *gui, GtkWidget *top)
 	}
 	g_list_free (providers);
 	
-	/* add a "None" option to the stores menu */
-	item = gtk_menu_item_new_with_label (_("None"));
-	g_object_set_data ((GObject *) item, "provider", NULL);
-	g_signal_connect (item, "activate", G_CALLBACK (source_type_changed), gui);
-	
-	gtk_menu_shell_append(GTK_MENU_SHELL(stores), item);
-	
-	gtk_widget_show (item);
-	
 	if (!fstore || !source_proto) {
-		fstore = item;
-		hstore = si;
+		fstore = none;
+		hstore = 0;
 	}
 	
 	/* set the menus on the optionmenus */
@@ -2116,7 +2339,8 @@ mail_account_gui_save (MailAccountGui *gui)
 	account = mail_config_get_account_by_name (new_name);
 	
 	if (account && account != new) {
-		e_notice (gui->account_name, GTK_MESSAGE_ERROR, _("You may not create two accounts with the same name."));
+		e_error_run((GtkWindow *)gtk_widget_get_toplevel((GtkWidget *)gui->account_name),
+			    "mail:account-notunique", NULL);
 		return FALSE;
 	}
 	
